@@ -67,6 +67,9 @@
 #' @export
 cpp_source <- function(file, code = NULL, env = parent.frame(), clean = TRUE, quiet = TRUE, cxx_std = Sys.getenv("CXX_STD", "CXX11"), dir = tempfile()) {
   stop_unless_installed(c("brio", "callr", "cli", "decor", "desc", "glue", "tibble", "vctrs"))
+  if (!missing(file) && !file.exists(file)) {
+    stop("Can't find `file` at this path:\n", file, "\n", call. = FALSE)
+  }
 
   dir.create(dir, showWarnings = FALSE, recursive = TRUE)
   dir.create(file.path(dir, "R"), showWarnings = FALSE)
@@ -106,9 +109,7 @@ cpp_source <- function(file, code = NULL, env = parent.frame(), clean = TRUE, qu
   #provide original path for error messages
   check_valid_attributes(all_decorations, file = orig_file_path)
 
-  cli_suppress(
-    funs <- get_registered_functions(all_decorations, "cpp11::register")
-  )
+  funs <- get_registered_functions(all_decorations, "cpp11::register", quiet = quiet)
   cpp_functions_definitions <- generate_cpp_functions(funs, package = package)
 
   cpp_path <- file.path(dirname(new_file_path), "cpp11.cpp")
