@@ -44,18 +44,20 @@ add_one(x)
 x
 
 ## ----error=TRUE---------------------------------------------------------------
+try({
 test_destructor_ok()
+})
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  test_destructor_bad()
-#  #> Error: oh no!
+# test_destructor_bad()
+# #> Error: oh no!
 
 ## -----------------------------------------------------------------------------
 set.seed(123)
 x <- sample(letters, 1e6, replace = TRUE)
 
 bench::mark(
-  test_extract_cpp11(x), 
+  test_extract_cpp11(x),
   test_extract_r_api(x)
 )
 
